@@ -4,11 +4,31 @@
 # include <config.h>
 #endif
 
+#ifdef HAVE_BYTESWAP_H
+# include <byteswap.h>
+#endif
+
+#ifdef HAVE_SYS_ENDIAN_H
+# include <sys/endian.h>
+#endif
+
+#ifdef HAVE_MACHINE_ENDIAN_H
+# include <machine/endian.h>
+#endif
+
+#ifdef HAVE_ENDIAN_H
+# include <endian.h>
+#endif
+
+#include "win32_comp.h"
+
 #ifdef USE_LTDL
 # include "../libltdl/ltdl.h"
 #else
 # ifdef HAVE_DLFCN_H
-#  include <dlfcn.h>
+#  ifndef WIN32
+#   include <dlfcn.h>
+#  endif
 # endif
 # define lt_dlexit() 0
 # define lt_dlinit() 0
@@ -16,7 +36,11 @@
 # define lt_dlsym(x,y) dlsym(x,y)
 # define lt_dlhandle void*
 # define lt_ptr_t void*
-# define lt_dlerror dlerror
+# ifndef WIN32
+#  define lt_dlerror dlerror
+# else 
+#  define lt_dlerror() 0
+# endif
 #endif
 
 #ifdef STDC_HEADERS
