@@ -17,7 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* $Id: mcrypt.c,v 1.2 2000/09/04 13:02:11 nmav Exp $ */
+/* $Id: mcrypt.c,v 1.3 2000/10/12 21:06:31 nmav Exp $ */
 
 /* Changed by Steve Underwood 1999/12/10 to allow an arbitrary number of 
  * streams of encryption. Currently the resulting code is probably not
@@ -97,7 +97,7 @@ static int internal_init_mcrypt(MCRYPT td, void *key, int lenofkey, void *IV)
 	return 0;
 }
 
-int internal_end_mcrypt(MCRYPT td)
+static int internal_end_mcrypt(MCRYPT td)
 {
 	mxfree(td->keyword_given, mcrypt_enc_get_key_size(td));
 	td->keyword_given = NULL;
@@ -114,11 +114,13 @@ int internal_end_mcrypt(MCRYPT td)
 
 /* Generic - High level functions */
 
+WIN32DLL_DEFINE
 int mcrypt_generic_init(const MCRYPT td, void *key, int lenofkey, void *IV)
 {
 	return internal_init_mcrypt(td, key, lenofkey, IV);
 }
 
+WIN32DLL_DEFINE
 int mcrypt_generic(MCRYPT td, void *plaintext, int len)
 {
 	int x;
@@ -127,6 +129,7 @@ int mcrypt_generic(MCRYPT td, void *plaintext, int len)
 	return x;
 }
 
+WIN32DLL_DEFINE
 int mdecrypt_generic(MCRYPT td, void *ciphertext, int len)
 {
 	int x;
@@ -134,6 +137,7 @@ int mdecrypt_generic(MCRYPT td, void *ciphertext, int len)
 	return x;
 }
 
+WIN32DLL_DEFINE
 int mcrypt_generic_end(const MCRYPT td)
 {
 	internal_end_mcrypt(td);
@@ -141,7 +145,7 @@ int mcrypt_generic_end(const MCRYPT td)
 	return 0;
 }
 
-
+WIN32DLL_DEFINE
 void mcrypt_perror(int err)
 {
 
@@ -170,6 +174,7 @@ void mcrypt_perror(int err)
 	return;
 }
 
+WIN32DLL_DEFINE
 int mcrypt_free(void *ptr)
 {
 	free(ptr);
