@@ -29,6 +29,7 @@
 extern int preloaded_symbols;
 #endif
 
+WIN32DLL_DEFINE
 int mcrypt_module_close(MCRYPT td)
 {
 
@@ -48,6 +49,7 @@ int mcrypt_module_close(MCRYPT td)
 }
 
 #ifndef USE_LTDL
+WIN32DLL_DEFINE
 void *mcrypt_dlopen_ext ( const char *filename) {
 	void *ret;
 	char full_path[1054];
@@ -58,7 +60,11 @@ void *mcrypt_dlopen_ext ( const char *filename) {
 	ret = dlopen(full_path, RTLD_LAZY);
 
 	if (ret==NULL) {
+#ifndef WIN32
 		strcat(full_path, ".so");
+#else
+		strcat(full_path, ".dll");
+#endif
 		ret = dlopen(full_path, RTLD_LAZY);
 	}
 	return ret;
@@ -66,6 +72,7 @@ void *mcrypt_dlopen_ext ( const char *filename) {
 }
 #endif
 
+WIN32DLL_DEFINE
 void *mcrypt_dlopen ( const char* a_directory, const char *m_directory, const char *filename) {
 	void* ret=NULL;
 
@@ -120,6 +127,7 @@ void *mcrypt_dlopen ( const char* a_directory, const char *m_directory, const ch
 
 }
 
+WIN32DLL_DEFINE
 MCRYPT mcrypt_module_open(char *algorithm,
 			  char *a_directory, char *mode, char *m_directory)
 {
@@ -171,6 +179,7 @@ MCRYPT mcrypt_module_open(char *algorithm,
 
 /* Modules' frontends */
 
+WIN32DLL_DEFINE
 int mcrypt_get_size(MCRYPT td)
 {
 	int (*_mcrypt_get_size) (void);
@@ -188,6 +197,7 @@ int mcrypt_get_size(MCRYPT td)
 	return _mcrypt_get_size();
 }
 
+WIN32DLL_DEFINE
 int mcrypt_mode_get_size(MCRYPT td)
 {
 	int (*_mcrypt_get_size) (void);
@@ -205,6 +215,7 @@ int mcrypt_mode_get_size(MCRYPT td)
 	return _mcrypt_get_size();
 }
 
+WIN32DLL_DEFINE
 void mcrypt_set_key(MCRYPT td, void *a, void *b, int c, void *d, int e)
 {
 	void (*__mcrypt_set_key_stream) (void *, void *, int, void *, int);
@@ -233,6 +244,7 @@ void mcrypt_set_key(MCRYPT td, void *a, void *b, int c, void *d, int e)
 	}
 }
 
+WIN32DLL_DEFINE
 int mcrypt_enc_set_state(MCRYPT td, void *iv, int size)
 {
 	int (*__mcrypt_set_state) (void *, void *, int);
@@ -250,7 +262,7 @@ int mcrypt_enc_set_state(MCRYPT td, void *iv, int size)
 	return __mcrypt_set_state(td->abuf, iv, size);
 }
 
-
+WIN32DLL_DEFINE
 int mcrypt_enc_get_block_size(MCRYPT td)
 {
 	int (*_mcrypt_get_block_size) (void);
@@ -259,7 +271,7 @@ int mcrypt_enc_get_block_size(MCRYPT td)
 	return _mcrypt_get_block_size();
 }
 
-
+WIN32DLL_DEFINE
 int mcrypt_get_algo_iv_size(MCRYPT td)
 {
 	int (*_mcrypt_get_algo_iv_size) (void);
@@ -271,7 +283,7 @@ int mcrypt_get_algo_iv_size(MCRYPT td)
 	return _mcrypt_get_algo_iv_size();
 }
 
-
+WIN32DLL_DEFINE
 int mcrypt_enc_get_iv_size(MCRYPT td)
 {
 	if (mcrypt_enc_is_block_algorithm_mode(td) == 1) {
@@ -281,6 +293,7 @@ int mcrypt_enc_get_iv_size(MCRYPT td)
 	}
 }
 
+WIN32DLL_DEFINE
 int mcrypt_enc_get_key_size(MCRYPT td)
 {
 	int (*_mcrypt_get_key_size) (void);
@@ -292,7 +305,7 @@ int mcrypt_enc_get_key_size(MCRYPT td)
 	return _mcrypt_get_key_size();
 }
 
-
+WIN32DLL_DEFINE
 int *mcrypt_enc_get_supported_key_sizes(MCRYPT td, int *len)
 {
 	int *(*_mcrypt_get_key_sizes) (int *);
@@ -308,7 +321,7 @@ int *mcrypt_enc_get_supported_key_sizes(MCRYPT td, int *len)
 	return size;
 }
 
-
+WIN32DLL_DEFINE
 int mcrypt_enc_is_block_algorithm(MCRYPT td)
 {
 	int (*_is_block_algorithm) (void);
@@ -320,7 +333,7 @@ int mcrypt_enc_is_block_algorithm(MCRYPT td)
 	return _is_block_algorithm();
 }
 
-
+WIN32DLL_DEFINE
 char *mcrypt_enc_get_algorithms_name(MCRYPT td)
 {
 	char *(*_mcrypt_get_algorithms_name) (void);
@@ -333,6 +346,7 @@ char *mcrypt_enc_get_algorithms_name(MCRYPT td)
 	return _mcrypt_get_algorithms_name();
 }
 
+WIN32DLL_DEFINE
 void mcrypt_block_encrypt(MCRYPT td, void *b)
 {
 	void (*_mcrypt_block_encrypt) (void *, void *);
@@ -344,6 +358,7 @@ void mcrypt_block_encrypt(MCRYPT td, void *b)
 	_mcrypt_block_encrypt(a, b);
 }
 
+WIN32DLL_DEFINE
 void mcrypt_block_decrypt(MCRYPT td, void *b)
 {
 	void (*_mcrypt_block_decrypt) (void *, void *);
@@ -354,6 +369,7 @@ void mcrypt_block_decrypt(MCRYPT td, void *b)
 	_mcrypt_block_decrypt(a, b);
 }
 
+WIN32DLL_DEFINE
 void mcrypt_stream_encrypt(MCRYPT td, void *b, int c)
 {
 	void (*_mcrypt_stream_encrypt) (void *, void *, int);
@@ -364,6 +380,7 @@ void mcrypt_stream_encrypt(MCRYPT td, void *b, int c)
 	_mcrypt_stream_encrypt(a, b, c);
 }
 
+WIN32DLL_DEFINE
 void mcrypt_stream_decrypt(MCRYPT td, void *b, int c)
 {
 	void (*_mcrypt_stream_decrypt) (void *, void *, int);
@@ -374,6 +391,7 @@ void mcrypt_stream_decrypt(MCRYPT td, void *b, int c)
 	_mcrypt_stream_decrypt(a, b, c);
 }
 
+WIN32DLL_DEFINE
 int init_mcrypt(MCRYPT td, void *buf, void *a, int b, void *c)
 {
 	int (*_init_mcrypt) (void *, void *, int, void *, int);
@@ -384,6 +402,7 @@ int init_mcrypt(MCRYPT td, void *buf, void *a, int b, void *c)
 	return _init_mcrypt(buf, a, b, c, mcrypt_enc_get_block_size(td));
 }
 
+WIN32DLL_DEFINE
 int end_mcrypt(MCRYPT td, void *buf)
 {
 	int (*_end_mcrypt) (void *);
@@ -394,6 +413,7 @@ int end_mcrypt(MCRYPT td, void *buf)
 	return _end_mcrypt(buf);
 }
 
+WIN32DLL_DEFINE
 int mcrypt(MCRYPT td, void *buf, void *a, int b)
 {
 	int (*_mcrypt) (void *, void *, int, int, void *, void *, void*);
@@ -403,6 +423,7 @@ int mcrypt(MCRYPT td, void *buf, void *a, int b)
 		       td->a_encrypt, td->a_decrypt);
 }
 
+WIN32DLL_DEFINE
 int mdecrypt(MCRYPT td, void *buf, void *a, int b)
 {
 	int (*_mdecrypt) (void *, void *, int, int, void *, void *, void*);
@@ -412,7 +433,7 @@ int mdecrypt(MCRYPT td, void *buf, void *a, int b)
 			 td->akey, td->a_encrypt, td->a_decrypt);
 }
 
-
+WIN32DLL_DEFINE
 char *mcrypt_enc_get_modes_name(MCRYPT td)
 {
 	char *(*_mcrypt_get_modes_name) (void);
@@ -424,7 +445,7 @@ char *mcrypt_enc_get_modes_name(MCRYPT td)
 	return _mcrypt_get_modes_name();
 }
 
-
+WIN32DLL_DEFINE
 int mcrypt_enc_is_block_mode(MCRYPT td)
 {
 	int (*_is_block_mode) (void);
@@ -436,6 +457,7 @@ int mcrypt_enc_is_block_mode(MCRYPT td)
 	return _is_block_mode();
 }
 
+WIN32DLL_DEFINE
 int mcrypt_enc_mode_has_iv(MCRYPT td)
 {
 	int (*_has_iv) (void);
@@ -447,7 +469,7 @@ int mcrypt_enc_mode_has_iv(MCRYPT td)
 	return _has_iv();
 }
 
-
+WIN32DLL_DEFINE
 int mcrypt_enc_is_block_algorithm_mode(MCRYPT td)
 {
 	int (*_is_a_block_mode) (void);
@@ -459,7 +481,7 @@ int mcrypt_enc_is_block_algorithm_mode(MCRYPT td)
 	return _is_a_block_mode();
 }
 
-
+WIN32DLL_DEFINE
 int mcrypt_enc_self_test(MCRYPT td)
 {
 	int (*_self_test) (void);
@@ -472,7 +494,7 @@ int mcrypt_enc_self_test(MCRYPT td)
 	return _self_test();
 }
 
-
+WIN32DLL_DEFINE
 int mcrypt_module_self_test(char *algorithm, char *a_directory)
 {
 	int i;
@@ -504,6 +526,7 @@ int mcrypt_module_self_test(char *algorithm, char *a_directory)
 	return i;
 }
 
+WIN32DLL_DEFINE
 int mcrypt_module_algorithm_version(char *algorithm, char *a_directory)
 {
 	int i;
@@ -534,6 +557,7 @@ int mcrypt_module_algorithm_version(char *algorithm, char *a_directory)
 	return i;
 }
 
+WIN32DLL_DEFINE
 int mcrypt_module_mode_version(char *mode, char *m_directory)
 {
 	int i;
@@ -564,7 +588,7 @@ int mcrypt_module_mode_version(char *mode, char *m_directory)
 	return i;
 }
 
-
+WIN32DLL_DEFINE
 int mcrypt_module_is_block_algorithm(char *algorithm, char *a_directory)
 {
 	int i;
@@ -596,7 +620,7 @@ int mcrypt_module_is_block_algorithm(char *algorithm, char *a_directory)
 	return i;
 }
 
-
+WIN32DLL_DEFINE
 int mcrypt_module_is_block_algorithm_mode(char *mode, char *m_directory)
 {
 	int i;
@@ -627,7 +651,7 @@ int mcrypt_module_is_block_algorithm_mode(char *mode, char *m_directory)
 	return i;
 }
 
-
+WIN32DLL_DEFINE
 int mcrypt_module_is_block_mode(char *mode, char *m_directory)
 {
 	int i;
@@ -658,6 +682,7 @@ int mcrypt_module_is_block_mode(char *mode, char *m_directory)
 	return i;
 }
 
+WIN32DLL_DEFINE
 int mcrypt_module_get_algo_block_size(char *algorithm, char *a_directory)
 {
 	int i;
@@ -688,6 +713,7 @@ int mcrypt_module_get_algo_block_size(char *algorithm, char *a_directory)
 	return i;
 }
 
+WIN32DLL_DEFINE
 int mcrypt_module_get_algo_key_size(char *algorithm, char *a_directory)
 {
 	int i;
@@ -718,7 +744,7 @@ int mcrypt_module_get_algo_key_size(char *algorithm, char *a_directory)
 	return i;
 }
 
-
+WIN32DLL_DEFINE
 int *mcrypt_module_get_algo_supported_key_sizes(char *algorithm,
 						char *a_directory,
 						int *len)
