@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 1998,1999 Nikos Mavroyanopoulos
+ * Copyright (C) 1998,1999,2000 Nikos Mavroyanopoulos
  *
  * This library is free software; you can redistribute it and/or modify it 
  * under the terms of the GNU Library General Public License as published 
@@ -37,95 +37,103 @@
 #define _mcrypt_algorithm_version arcfour_LTX__mcrypt_algorithm_version
 #endif
 
-#define swap_byte(x,y) t = *(x); *(x) = *(y); *(y) = t
 
-void _mcrypt_set_key(arcfour_key *key, word8 *key_data_ptr, int key_data_len, char* IV, int ivlen)
+/* key is the state that should be allocated by the caller */
+WIN32DLL_DEFINE
+void _mcrypt_set_key(arcfour_key *key, word8 *key_data, int key_len, char* IV, int iv_len)
 {
-  word8 t;
-  word8 index1;
-  word8 index2;
+  word8 tmp, j;
   word8* state;
-  short counter;
+  short i;
 
   state = key->state;
   
-  for(counter = 0; counter < 256; counter++)
-	  state[counter] = counter;
-  key->x = 0;
-  key->y = 0;
-  index1 = 0;
-  index2 = 0;
-
-  for(counter = 0; counter < 256; counter++)  {
-	index2 = ( key_data_ptr[index1] + state[counter] + index2) % 256;
-	swap_byte(&state[counter], &state[index2]);
-	index1 = (index1 + 1) % key_data_len;
+  for(i = 0; i < 256; i++)
+	  state[i] = i;
+	  
+  key->i = 0;
+  key->j = 0;
+ 
+  j=0;
+  
+  for(i=0; i<256; i++) {
+ 	j = (j+state[i]+key_data[i % key_len]);
+	tmp = state[i];
+	state[i] = state[j];
+	state[j] = tmp;
   }
 
+  tmp = j = i = 0;
+ 
 }
 
+#define I key->i
+#define J key->j
+#define STATE key->state
+WIN32DLL_DEFINE
 void _mcrypt_encrypt(arcfour_key *key, word8 *buffer_ptr, int buffer_len)
 {
-  word8 t;
-  word8 x;
-  word8 y;
-  word8* state;
-  word8 xorIndex;
-  short counter;
-
-  x = key->x;
-  y = key->y;
-  state = &key->state[0];
+  word8 tmp;
+  int counter;
+  
   for(counter = 0; counter < buffer_len; counter++)
   {
-    x = (x + 1) % 256;
-    y = (state[x] + y) % 256;
-    swap_byte(&state[x], &state[y]);
-    xorIndex = (state[x] + state[y]) % 256;
-    buffer_ptr[counter] ^= state[xorIndex];
+    I++;
+    J += STATE[I];
+    
+    /* swap STATE[I] and STATE[J] */
+    tmp = STATE[I];
+    STATE[I]=STATE[J];
+    STATE[J]=tmp;
+    
+    tmp = STATE[I]+STATE[J];
+    buffer_ptr[counter] ^= STATE[tmp];
   }
-  key->x = x;
-  key->y = y;
 }
 
+/* this is the same with mcrypt_encrypt */
+WIN32DLL_DEFINE
 void _mcrypt_decrypt(arcfour_key *key, word8 *buffer_ptr, int buffer_len)
 {
-  word8 t;
-  word8 x;
-  word8 y;
-  word8* state;
-  word8 xorIndex;
-  short counter;
-
-  x = key->x;
-  y = key->y;
-  state = &key->state[0];
+  word8 tmp;
+  int counter;
+  
   for(counter = 0; counter < buffer_len; counter++)
   {
-    x = (x + 1) % 256;
-    y = (state[x] + y) % 256;
-    swap_byte(&state[x], &state[y]);
-    xorIndex = (state[x] + state[y]) % 256;
-    buffer_ptr[counter] ^= state[xorIndex];
+    I++;
+    J += STATE[I];
+    
+    /* swap STATE[I] and STATE[J] */
+    tmp = STATE[I];
+    STATE[I]=STATE[J];
+    STATE[J]=tmp;
+    
+    tmp = STATE[I]+STATE[J];
+    buffer_ptr[counter] ^= STATE[tmp];
   }
-  key->x = x;
-  key->y = y;
 }
 
-
+WIN32DLL_DEFINE
 int _mcrypt_get_size () {return sizeof(arcfour_key);}
+WIN32DLL_DEFINE
 int _mcrypt_get_block_size() { return 1; }
+WIN32DLL_DEFINE
 int _mcrypt_get_algo_iv_size() { return 0; }
+WIN32DLL_DEFINE
 int _is_block_algorithm() { return 0; }
+WIN32DLL_DEFINE
 int _mcrypt_get_key_size() { return 256; }
+WIN32DLL_DEFINE
 int* _mcrypt_get_supported_key_sizes(int *len) {
 	*len=0;
 	return NULL;
 }
+WIN32DLL_DEFINE
 char * _mcrypt_get_algorithms_name() { char*x; x=malloc(5); strcpy(x, "RC4"); return x;}
 
 #define CIPHER "3abaa03a286e24c4196d292ab72934d6854c3eee"
 
+WIN32DLL_DEFINE
 int _mcrypt_self_test() {
 	char *keyword;
 	unsigned char *plaintext;
@@ -170,7 +178,8 @@ int _mcrypt_self_test() {
 	return 0;
 }
 
+WIN32DLL_DEFINE
 word32 _mcrypt_algorithm_version() {
-        return 19991210;
+        return 20001001;
 }
 
