@@ -19,7 +19,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: rijndael-128.c,v 1.2 2000/09/16 02:01:38 nmav Exp $ */
+/* $Id: rijndael-128.c,v 1.4 2000/10/12 21:06:31 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
@@ -187,6 +187,7 @@ void _mcrypt_rijndael_gentables(void)
     }
 }
 
+WIN32DLL_DEFINE
 void _mcrypt_set_key( RI* rinst, word8 *key, int nk)
 { /* blocksize=32*nb bits. Key=32*nk bits */
   /* currently nb,bk = 4, 6 or 8          */
@@ -268,6 +269,7 @@ void _mcrypt_set_key( RI* rinst, word8 *key, int nk)
  * Instead of just one ftable[], I could have 4, the other     *
  * 3 pre-rotated to save the ROTL8, ROTL16 and ROTL24 overhead */ 
 
+WIN32DLL_DEFINE
 void _mcrypt_encrypt(RI *rinst, word8 *buff)
 {
     int i,j,k,m;
@@ -315,6 +317,7 @@ void _mcrypt_encrypt(RI *rinst, word8 *buff)
     return;
 }
 
+WIN32DLL_DEFINE
 void _mcrypt_decrypt(RI *rinst, word8 *buff)
 {
     int i,j,k,m;
@@ -362,10 +365,15 @@ void _mcrypt_decrypt(RI *rinst, word8 *buff)
 }
 
 
+WIN32DLL_DEFINE
 int _mcrypt_get_size () {return sizeof(RI);}
+WIN32DLL_DEFINE
 int _mcrypt_get_block_size() { return 16; }
+WIN32DLL_DEFINE
 int _is_block_algorithm() { return 1; }
+WIN32DLL_DEFINE
 int _mcrypt_get_key_size() { return 32; }
+WIN32DLL_DEFINE
 int* _mcrypt_get_supported_key_sizes(int *len) {
         int* size=malloc(3*sizeof(int));
         size[0]=16;
@@ -374,31 +382,36 @@ int* _mcrypt_get_supported_key_sizes(int *len) {
 	*len=3;
         return size;
 }
+WIN32DLL_DEFINE
 char * _mcrypt_get_algorithms_name() { char*x; x=malloc(14); strcpy(x, "Rijndael-128"); return x;}
 
-#define CIPHER "f4a2dc1a12c0da537d94f956d4132fc1"
+#define CIPHER "5352e43763eec1a8502433d6d520b1f0"
 
+WIN32DLL_DEFINE
 int _mcrypt_self_test() {
 	char *keyword;
 	unsigned char *plaintext;
         unsigned char *ciphertext;
         int blocksize=_mcrypt_get_block_size(), j;
+        int keysize=16;
         void *key;
         unsigned char cipher_tmp[200];
-                         
-	keyword = calloc(1, _mcrypt_get_key_size());
-        for (j=0; j< _mcrypt_get_key_size(); j++) {
-	        keyword[j]=((j*2+10)%256);
+
+	keyword = calloc(1, keysize);
+        for (j=0; j< keysize; j++) {
+	        keyword[j]=0; 
 	}
+	keyword[0]=1;
 	ciphertext = malloc(blocksize);
         plaintext = malloc(blocksize);
         for (j=0; j< blocksize; j++) {
-	        plaintext[j]=j%256;
+	        plaintext[j]=j;
 	}
+
 	key=malloc(_mcrypt_get_size());
 	memcpy(ciphertext, plaintext, blocksize);
 
-	_mcrypt_set_key( key, (void*)keyword, _mcrypt_get_key_size());
+	_mcrypt_set_key( key, (void*)keyword, keysize);
 	_mcrypt_encrypt( key, (void*)ciphertext);
 
         for (j = 0; j < blocksize; j++) {
@@ -420,6 +433,7 @@ int _mcrypt_self_test() {
 	return 0;
 }
 
+WIN32DLL_DEFINE
 word32 _mcrypt_algorithm_version() {
 	return 19991129;
 }
